@@ -205,6 +205,6 @@ class CidClient:
         # TODO this api is named funy}
         return self._smart_post("/v1/instance/nodes", payload={"crate_ids": [crate_id], })
 
-    def _fetch_instance_tree(self, farme_id):
+    def _fetch_instance_tree(self, frame_id):
         # TODO this api is named funy}
         return self._smart_post("/v1/tree/frame/query", payload={"frame_id": frame_id, })
